<?php
/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://etracker.com
 * @since      1.0.0
 *
 * @package    Etracker
 * @subpackage Etracker/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Etracker
 * @subpackage Etracker/includes
 * @author     etracker GmbH <support@etracker.com>
 */
class Etracker {
	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Etracker_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The tracklet that's responsible for generating etracker tracklet.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Etracker_Tracklet    $tracklet    Generates etracker tracklet.
	 */
	protected $tracklet;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'ETRACKER_VERSION' ) ) {
			$this->version = ETRACKER_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'etracker';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		$this->configure_tracklet();
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Etracker_Loader. Orchestrates the hooks of the plugin.
	 * - Etracker_I18n. Defines internationalization functionality.
	 * - Etracker_Admin. Defines all hooks for the admin area.
	 * - Etracker_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {
		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-etracker-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-etracker-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-etracker-admin.php';

		/**
		 * The class responsible for building etracker tracklet.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-etracker-tracklet.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-etracker-public.php';

		$this->loader   = new Etracker_Loader();
		$this->tracklet = new Etracker_Tracklet( $this->get_plugin_name(), $this->get_version() );
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Etracker_I18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {
		$plugin_i18n = new Etracker_I18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {
		$plugin_admin = new Etracker_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_menu', $plugin_admin, 'add_admin_menu' );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'settings_init' );
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {
		$plugin_public = new Etracker_Public( $this->get_plugin_name(), $this->get_version(), $this->tracklet );

		$this->loader->add_action( 'wp_head', $plugin_public, 'html_head_code' );
		$this->loader->add_filter( 'document_title_parts', $this->tracklet, 'document_title_parts', PHP_INT_MAX, 1 );
		$this->loader->add_filter( 'wpseo_title', $this->tracklet, 'wpseo_title', PHP_INT_MAX, 1 );
	}

	/**
	 * Get plugin specific WordPress setting.
	 *
	 * @param string $name       Settings name.
	 * @param string $default    Default value if setting does not exist.
	 * @return string|boolean|integer
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function get_setting( $name, $default = false ) {
		$options = get_option( 'etracker_settings' );
		return ( empty( $options[ $name ] ) ) ? $default : $options[ $name ];
	}

	/**
	 * Setup tracklet with all settings from backend.
	 *
	 * Defines default settings for tracklet.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function configure_tracklet() {
		$this->tracklet->set_secure_code(
			$this->get_setting( 'etracker_secure_code', '' )
		);
		$this->tracklet->set_respect_dnt(
			( 'true' === $this->get_setting( 'etracker_respect_dnt', 'true' ) ) ? true : false
		);
		$this->tracklet->set_block_cookies(
			( 'true' === $this->get_setting( 'etracker_block_cookies', 'true' ) ) ? true : false
		);
		$this->tracklet->set_disable_et_pagename(
			( 'true' === $this->get_setting( 'etracker_disable_et_pagename', 'false' ) ) ? true : false
		);
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Etracker_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
